@@ -1,5 +1,5 @@
 package Test::Requires::Git;
-$Test::Requires::Git::VERSION = '1.004';
+$Test::Requires::Git::VERSION = '1.005';
 use strict;
 use warnings;
 
@@ -49,14 +49,25 @@ sub import {
 
 sub _extract_arguments {
     my (@args) = @_;
-    croak 'Odd number of elements in git specification' if @args % 2;
 
     my ( %args, @spec );
-    while ( my ( $key, $val ) = splice @args, 0, 2 ) {
+    while (@args) {
+
+        # assume a lone parameter is a minimum git version
+        unshift @args, 'version_ge' if @args == 1;
+
+        my ( $key, $val ) = splice @args, 0, 2;
         if ( $key =~ /^(?:git|skip)/ ) {
             croak "Duplicate '$key' argument" if exists $args{$key};
             $args{$key} = $val;
         }
+        elsif ( !exists $check{$key} ) {
+            if ( @args % 2 ) {    # odd number of arguments (see above)
+                unshift @args, version_ge => $key, $val;
+                redo;
+            }
+            croak "Unknown git specification '$key'";
+        }
         else {
             push @spec, $key, $val;
         }
@@ -81,7 +92,6 @@ sub test_requires_git {
     my ( $ok, $why ) = ( 1, '' );
     if ($version) {
         while ( my ( $spec, $arg ) = splice @spec, 0, 2 ) {
-            croak "Unknown git specification '$spec'" if !exists $check{$spec};
             if ( !$check{$spec}->( $version, $arg ) ) {
                 $ok  = 0;
                 $why = "$version $spec $arg";
@@ -166,6 +176,9 @@ If the checks fail, then all tests will be I<skipped>.
     # skip all
     test_requires_git version_ge => '1.6.5';
 
+    # giving no operator implies version_ge
+    test_requires_git '1.6.5';
+
     # skip 2
   SKIP: {
         test_requires_git
@@ -202,18 +215,21 @@ If no condition is given, C<test_requires_git> will simply check if C<git>
 is available.
 
 C<use Test::Requires::Git> always calls C<test_requires_git> with the
-given arguments. If you don't want C<test_requires_git> to be called,
-write C<use Test::Requires::Git -nocheck;> instead.
+given arguments. If you don't want C<test_requires_git> to be called
+at import time, write this instead:
+
+    use Test::Requires::Git -nocheck;
 
 Passing the C<git> parameter to C<use Test::Requires::Git> will override
 it for the rest of the program run.
 
 =head1 GIT VERSION CHECKING
 
-The following version checks are currently supported.
+The actual comparison is handled by L<Git::Version::Compare>, so the
+strings can be version numbers, tags from C<git.git> or the output of
+C<git version> or C<git describe>.
 
-Note that versions C<1.0.0a> and C<1.0.0b> are respectively turned into
-C<1.0.1> and C<1.0.2> internally.
+The following version checks are currently supported:
 
 =head2 version_eq
 
@@ -263,9 +279,18 @@ Aliases: C<version_ge>, C<ge>, C<E<gt>=>.
 
 Passes if the current B<git> version is I<greater than or equal > C<$version>.
 
+As a special shortcut for the most common case, a lone version number
+is turned into a C<version_ge> check, so the following two lines are
+exactly equivalent:
+
+    test_requires_git version_ge => '1.6.5';
+
+    # version_ge implied
+    test_requires_git '1.6.5';
+
 =head1 SEE ALSO
 
-L<Test::Requires>
+L<Test::Requires>, L<Git::Version::Compare>.
 
 =head1 ACKNOWLEDGEMENTS
 
@@ -279,7 +304,7 @@ Philippe Bruhat (BooK), <book@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2015 Philippe Bruhat (BooK), all rights reserved.
+Copyright 2015-2016 Philippe Bruhat (BooK), all rights reserved.
 
 =head1 LICENSE
 
